==> biz-www-2.21-20170301.062723-2-sources.jar: com/baijia/tianxiao/biz/www/authentication/AuthenticateManagerImpl.java <==

/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */

package com.baijia.tianxiao.biz.www.authentication;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;

import com.baijia.tianxiao.biz.www.IllegalAccessCtrlService;
import com.baijia.tianxiao.biz.www.authentication.dto.TXLoginAccountDto;
import com.baijia.tianxiao.dto.WebResponse;
import com.baijia.tianxiao.enums.CommonErrorCode;
import com.baijia.tianxiao.exception.BussinessException;
import com.google.common.collect.Lists;

import lombok.Data;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;

/**
 * @title AuthenticateManagerImpl
 * @desc O(∩_∩)O~
 * @author caoliang
 * @date 2016年8月24日
 * @version 1.0
 */
@Data
@Slf4j
public class AuthenticateManagerImpl implements AuthenticateManager {

    @Getter
    private static final String LOGIN_KEY_PREFIX = "tx_login_code_";
    private List<AbstractAuthenticateHandler> handlers;

    @Autowired
    private IllegalAccessCtrlService accessCtrService;

    @Override
    public List<TXLoginAccountDto> authenticate(Credential credential, Map<String, Object> options)
        throws Exception {
        List<TXLoginAccountDto> loginDtos = Lists.newArrayList();
        log.info("login credential:{}", credential);
        String redisKey = LOGIN_KEY_PREFIX + credential.getMobile();
        if (accessCtrService.isLocked(redisKey)) {
            throw new BussinessException(CommonErrorCode.BUSINESS_ERROR, "账户已被锁定，请1小时后再试");
        }
        boolean succAuthenticate = false;
        log.info("handlers:{}", handlers);
        for (AbstractAuthenticateHandler handler : handlers) {
            if (handler.authenticate(credential, loginDtos, options)) {
                succAuthenticate = true;
            }
        }
        if (!succAuthenticate) {
            log.debug("login fail");
            WebResponse<Object> detectRes = accessCtrService.detect(redisKey);
            throw new BussinessException(CommonErrorCode.PARAM_ERROR, detectRes.getMsg());
        }

        log.info("login loginDtos:{}", loginDtos);
        return loginDtos;
    }
}

==> biz-www-2.45.0-20171102.162402-30-sources.jar: com/baijia/tianxiao/biz/www/authentication/AuthenticateManagerImpl.java <==

/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */

package com.baijia.tianxiao.biz.www.authentication;

import java.util.List;
import java.util.Map;

import com.baijia.tianxiao.enums.RedisKeyEnums;
import org.springframework.beans.factory.annotation.Autowired;

import com.baijia.tianxiao.biz.www.IllegalAccessCtrlService;
import com.baijia.tianxiao.biz.www.authentication.dto.TXLoginAccountDto;
import com.baijia.tianxiao.dto.WebResponse;
import com.baijia.tianxiao.enums.CommonErrorCode;
import com.baijia.tianxiao.exception.BussinessException;
import com.google.common.collect.Lists;

import lombok.Data;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;

/**
 * @title AuthenticateManagerImpl
 * @desc O(∩_∩)O~
 * @author caoliang
 * @date 2016年8月24日
 * @version 1.0
 */
@Data
@Slf4j
public class AuthenticateManagerImpl implements AuthenticateManager {

//    @Getter
//    private static final String LOGIN_KEY_PREFIX = "tx_login_code_";
    private List<AbstractAuthenticateHandler> handlers;

    @Autowired
    private IllegalAccessCtrlService accessCtrService;

    @Override
    public List<TXLoginAccountDto> authenticate(Credential credential, Map<String, Object> options)
        throws Exception {
        List<TXLoginAccountDto> loginDtos = Lists.newArrayList();
        log.info("login credential:{}", credential);
        String redisKey = RedisKeyEnums.M.LOGIN_KEY_PREFIX.getRedisKey() + credential.getMobile();
        if (accessCtrService.isLocked(redisKey)) {
            throw new BussinessException(CommonErrorCode.BUSINESS_ERROR, "账户已被锁定，请1小时后再试");
        }
        boolean succAuthenticate = false;
        log.info("handlers:{}", handlers);
        for (AbstractAuthenticateHandler handler : handlers) {
            if (handler.authenticate(credential, loginDtos, options)) {
                succAuthenticate = true;
            }
        }
        if (!succAuthenticate) {
            log.debug("login fail");
            WebResponse<Object> detectRes = accessCtrService.detect(redisKey);
            throw new BussinessException(CommonErrorCode.PARAM_ERROR, detectRes.getMsg());
        }

        log.info("login loginDtos:{}", loginDtos);
        return loginDtos;
    }
}
